===============================
PyGSL's reference documentation
===============================

.. toctree::
   	    	      
    copyright
    install
    readme_distributors
    interfacedesign
    errors
    ieee
    const
    freedoc
    
Front Matter
============

Copyright © 2002,2005 The pygsl Team.

Permission is granted to copy, distribute and/or modify this document
under the terms of the GNU Free Documentation License, Version 1.1 or
any later version published by the Free Software Foundation; with no
Invariant Sections, no Front-Cover Texts, and no Back-Cover Texts. A
copy of the license is included in section
[cha:free-documentation-license] entitled “GNU Free Documentation
License”.







.. [1]
   Note that it appears that this is the number of terms *beyond* the
   first term that are used. I.e. there are a total of
   :math:`\var{terms_used}+1` terms:
 
..   .. math::
..
..      \var{sum_plain} = 
..            \sum_{n=0}^{\var{terms_used}}
..            a_{n}

.. _pygsl-discuss@lists.sourceforge.net: pygsl-discuss@lists.sourceforge.net
